@@ -102,6 +102,7 @@ TENTACLES_PATH = "tentacles"
 DEFAULT_BOT_PATH = CURRENT_DIR_PATH
 TENTACLES_BACKTESTING_PATH = "Backtesting"
 TENTACLES_EVALUATOR_PATH = "Evaluator"
+TENTACLES_PROFILES_PATH = "profiles"
 TENTACLES_INTERFACES_PATH = "Interfaces"
 TENTACLES_NOTIFIERS_PATH = "Notifiers"
 TENTACLES_SERVICES_PATH = "Services"
@@ -167,6 +168,7 @@ TENTACLES_FOLDERS_ARCH = {
             TENTACLES_BACKTESTING_THIRD_LEVEL_SOCIAL_PATH
         ]
     },
+    TENTACLES_PROFILES_PATH: [],
     TENTACLES_EVALUATOR_PATH: [
         TENTACLES_EVALUATOR_REALTIME_PATH,
         TENTACLES_EVALUATOR_SOCIAL_PATH,
